@@ -16,7 +16,7 @@ import actores
 import imagenes
 import sonidos
 import utils
-import interpolaciones
+from interpolaciones import Lineal
 import dispatch
 import eventos
 import habilidades
@@ -35,11 +35,14 @@ from colisiones import Colisiones
 mundo = None
 colisiones = Colisiones()
 
-def iniciar():
+def iniciar(ancho=640, alto=480, titulo='Pilas'):
     global mundo
-    mundo = Mundo()
+    mundo = Mundo(ancho, alto, titulo)
     escenas.Normal()
 
+def terminar():
+    global mundo
+    mundo.terminar()
 
 def ejecutar():
     "Pone en funcionamiento el ejecutar principal."
@@ -59,30 +62,36 @@ def ejecutar_en_segundo_plano():
     bg.start()
 
 
-def interpolar(*values, **kv):
-    "Retorna un objeto de interlacion que se puede asignar a una propiedad."
+def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
+    """Retorna un objeto que representa cambios de atributos progresivos.
+    
+    El resultado de esta función se puede aplicar a varios atributos
+    de los actores, por ejemplo::
+        
+        bomba = pilas.actores.Bomba()
+        bomba.escala = pilas.interpolar(3)
 
-    if 'duracion' in kv:
-        duration = kv.pop('duracion')
-    else:
-        duration = 5
+    Esta función también admite otros parámetros cómo:
 
-    if 'demora' in kv:
-        delay = kv.pop('demora')
-    else:
-        delay = 0
+        - duracion: es la cantidad de segundos que demorará toda la interpolación.
+        - demora: cuantos segundos se deben esperar antes de iniciar.
+        - tipo: es el algoritmo de la interpolación, puede ser 'lineal'.
+    """
 
-    if 'tipo' in kv:
-        tipo = kv.pop('tipo')
-    else:
-        tipo = 'lineal'
+    algoritmos = {
+            'lineal': Lineal,
+            }
 
-    if tipo == 'lineal':
-        clase = interpolaciones.Lineal
+    if algoritmos.has_key('lineal'):
+        clase = algoritmos[tipo]
     else:
         raise ValueError("El tipo de interpolacion %s es invalido" %(tipo))
 
-    return clase(values, duration, delay)
+    # Permite que los valores de interpolacion sean un numero o una lista.
+    if not isinstance(valor_o_valores, list):
+        valor_o_valores = [valor_o_valores]
+
+    return clase(valor_o_valores, duracion, demora)
 
 
 def avisar(mensaje):
