@@ -5,17 +5,31 @@
 # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
 #
 # Website - http://www.pilas-engine.com.ar
-
 import os
 import interpolaciones
 import pilas
 from PySFML import sf
 import sys
 import subprocess
+import math
+
+
+PATH = os.path.dirname(os.path.abspath(__file__))
+
+
+def cargar_autocompletado():
+    "Carga los modulos de python para autocompletar desde la consola interactiva."
+    import rlcompleter
+    import readline
+
+    readline.parse_and_bind("tab: complete")
 
 def hacer_flotante_la_ventana():
     "Hace flotante la ventana para i3 (el manejador de ventanas que utiliza hugo...)"
-    subprocess.call(['i3-msg', 't'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    try:
+        subprocess.call(['i3-msg', 't'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    except OSError:
+        pass
 
 def centrar_la_ventana(app):
     "Coloca la ventana principal en el centro del escritorio."
@@ -46,7 +60,7 @@ def obtener_ruta_al_recurso(ruta):
     función intentará dar con el archivo en cuestión.
     """
 
-    dirs = ['./', os.path.dirname(sys.argv[0]), 'data', pilas.path, pilas.path + '/data']
+    dirs = ['./', os.path.dirname(sys.argv[0]), 'data', PATH, PATH + '/data']
 
     for x in dirs:
         full_path = os.path.join(x, ruta)
@@ -67,3 +81,18 @@ def esta_en_sesion_interactiva():
     except AttributeError:
         return False
 
+def distancia(a, b):
+    "Retorna la distancia entre dos numeros."
+    return abs(b - a)
+
+def distancia_entre_dos_puntos((x1, y1), (x2, y2)):
+    "Retorna la distancia entre dos puntos en dos dimensiones."
+    return math.sqrt(distancia(x1, x2) ** 2 + distancia(y1, y2) ** 2)
+
+def distancia_entre_dos_actores(a, b):
+    return distancia_entre_dos_puntos((a.x, a.y), (b.x, b.y))
+
+def colisionan(a, b):
+    "Retorna True si dos actores estan en contacto."
+    return distancia_entre_dos_actores(a, b) < a.radio_de_colision + b.radio_de_colision
+    
